@@ -438,7 +438,15 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
             //qDebug("value: ", value);
 
             var attributes = this.getPropertyAttributes(group, title);
-            var propertyTypeId = attributes.getPropertyTypeId();
+            //var propertyTypeId = attributes.getPropertyTypeId();
+            var propertyTypeId = RPropertyTypeId.getPropertyTypeId(group, title);
+
+            if (propertyTypeId.getId()===-1) {
+                // property is custom property
+                // make sure it knows it's titles, etc:
+                propertyTypeId.setCustomPropertyTitle(group);
+                propertyTypeId.setCustomPropertyName(title);
+            }
 
             //qDebug("isMixed: ", attributes.isMixed());
 
@@ -573,8 +581,18 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
 
                 var controls = undefined;
                 if (!isNull(gridLayout)) {
-                    // don't display any Z values:
-                    if (RSettings.getBoolValue("PropertyEditor/ShowZCoordinates", false)===false && title==="Z" && !propertyTypeId.isCustom()) {
+                    // don't display any Z values or polyline elevation:
+                    var hide = false;
+                    if (!propertyTypeId.isCustom()) {
+                        if (RSettings.getBoolValue("PropertyEditor/ShowZCoordinates", false)===false) {
+                            if (title===RPolylineEntity.PropertyVertexNZ.getPropertyTitle() ||
+                                title===RPolylineEntity.PropertyElevation.getPropertyTitle()) {
+                                hide = true;
+                            }
+                        }
+                    }
+
+                    if (hide) {
                         controls = undefined;
                     }
                     else {
@@ -755,6 +773,20 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
         }
     }
 
+    // property available on request:
+    // add button to request all properties:
+    if (attributes.isOnRequest()) {
+        var requestAllButton = new QToolButton(this.geometryGroup);
+        requestAllButton.objectName = objectName + "_request";
+        requestAllButton.text = qsTr("Show");
+        requestAllButton.toolTip = qsTr("Show all properties");
+        requestAllButton.clicked.connect(this, "requestAllProperties");
+        requestAllButton.setSizePolicy(QSizePolicy.Ignored, QSizePolicy.Preferred);
+
+        return new Array(requestAllButton);
+    }
+
+
     // Layer:
 //    if (propertyTypeId.getId()===REntity.PropertyLayer.getId()) {
 //        WidgetFactory.initLayerCombo(control, EAction.getDocument());
@@ -906,6 +938,10 @@ PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyT
         if (attributes.isAngleType()) {
             control.setAngle(true);
         }
+        // TODO: support scale in RMathLineEdit:
+//        if (attributes.isScaleType()) {
+//            control.setScale(true);
+//        }
         control.objectName = objectName;
     }
 
@@ -1260,6 +1296,24 @@ PropertyEditorImpl.prototype.filterChanged = function() {
     this.updateFromDocument(doc, false, entityTypeFilter, true);
 };
 
+/**
+ * Called when the user requests all properties to be shown.
+ */
+PropertyEditorImpl.prototype.requestAllProperties = function() {
+    var doc = EAction.getDocument();
+    if (isNull(doc)) {
+        return;
+    }
+
+    var selectionCombo = this.widget.findChild("Selection");
+    var entityTypeFilter = selectionCombo.itemData(selectionCombo.currentIndex);
+    if (isNull(entityTypeFilter)) {
+        entityTypeFilter = RS.EntityAll;
+    }
+
+    this.updateFromDocument(doc, false, entityTypeFilter, true, true);
+};
+
 PropertyEditorImpl.prototype.getAdjustedPropertyValue = function(propertyTypeId) {
     // show handle as hex reprensentation (string):
     if (propertyTypeId.getId()===RObject.PropertyHandle.getId()) {
